local L = LibStub("AceLocale-3.0"):GetLocale("LCI")

-- [[Shared Variables]] --
local LCI_Media = "Interface\\AddOns\\LCI\\Media\\"
local LCI_Font = "Fonts\\FRIZQT__.ttf"
LCI_resFound = false
LCI_resolutions = {
	"1920x1080",
	Res2, --1680x1050
	Res3, --1600x1200
	Res4, --1600x1024
	Res5, --1600x900
	Res6, --1440x900
	Res7, --1400x1050
	Res8, --1366x768
	Res9, --1360x768
	Res10, --1280x1024
	Res11, --1280x800
	Res12, --1280x768
	Res13, --1280x720
	Res14, --1176x664
	Res15, --1152x864
	Res16, --1024x768
	Res17, --800x600
	Res18, --720x576
}

-- [[Shared Functions]] --
local function Button_OnEnter(self)
	self:GetNormalTexture():SetVertexColor(1, 0, 1)
end

local function Button_OnLeave(self)
	self:GetNormalTexture():SetVertexColor(1, 1, 1)
end

-- [[Shared Buttons]] --
function LCI:Continue_Button()
	LCI_Continue = CreateFrame("Button", "LCIContinueButton", SetupFrame)
	LCI_Continue:SetPoint("BOTTOMLEFT", SetupFrame.bg1, 50, 60)
	LCI_Continue:SetSize(100, 45)
	LCI_Continue:SetNormalTexture(LCI_Media .. "button1")
	LCI_Continue:SetScript("OnEnter", Button_OnEnter)
	LCI_Continue:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Continue Button Text]] --
	LCI_Continue.txt = LCI_Continue:CreateFontString(nil, "OVERLAY")
	LCI_Continue.txt:SetPoint("CENTER", LCI_Continue)
	LCI_Continue.txt:SetFont(LCI_Font, 14)
	LCI_Continue.txt:SetText(L["Continue"])
	
	-- [[Continue Button Script]] --
	LCI_Continue:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		-- Page 1 --
		if SetupFrame.pg1txt:IsShown() and SetupFrame.bg1:IsShown() then
			SetupFrame.pg1txt:Hide()
			SetupFrame.bg1:Hide()
			
			-- Check user's resolution --
			local index = GetCurrentResolution()
			local selectRes = select(index, GetScreenResolutions());
			
			for k,v in ipairs(LCI_resolutions) do
				if v == selectRes then
					LCI_resFound = true
				end
			end
			
			if resFound == true then
				LCI.db.profile.ResTypeSet = selectRes
			end
			
			LCI:SetupPage2()
			LCI_Continue:SetPoint("BOTTOMLEFT", SetupFrame.bg2, 50, 60)
			LCI_Cancel:SetPoint("BOTTOMRIGHT", SetupFrame.bg2, -50, 60)
		-- Page 2 --
		elseif SetupFrame.pg2txt:IsShown() and SetupFrame.bg2:IsShown() then
			SetupFrame.pg2txt:Hide()
			LCI_Select:Hide()
			LCI:SetupPage3()
		-- Page 2.5 --
		elseif (SetupFrame.rwtxt ~= nil) and SetupFrame.rwtxt:IsShown() and SetupFrame.bg2:IsShown() then
			SetupFrame.rwtxt:Hide()
			LCI_Res1:Hide()
			LCI_Res2:Hide()
			LCI_Res3:Hide()
			LCI_Res4:Hide()
			LCI_Res5:Hide()
			LCI_Res6:Hide()
			LCI_Res7:Hide()
			LCI_Res8:Hide()
			LCI_Res9:Hide()
			LCI_Res10:Hide()
			LCI_Res11:Hide()
			LCI_Res12:Hide()
			LCI_Res13:Hide()
			LCI_Res14:Hide()
			LCI_Res15:Hide()
			LCI_Res16:Hide()
			LCI_Res17:Hide()
			LCI_Res18:Hide()
			LCI:SetupPage3()
		-- Page 3 --
		elseif SetupFrame.pg3txt:IsShown() and SetupFrame.bg2:IsShown() then
			SetupFrame.pg3txt:Hide()
			LCI_Layout_H:Hide()
			LCI_Layout_TD:Hide()
			LCI:SetupPage4()
		elseif SetupFrame.pg4txt:IsShown() and SetupFrame.bg2:IsShown() then
			SetupFrame.pg4txt:Hide()
			LCI_Continue:Hide()
			LCI:SetupPage5()
		else
			LCI_Continue:Hide()
		end
	end)
end

function LCI:Cancel_Button()
	LCI_Cancel = CreateFrame("Button", nil, SetupFrame)
	LCI_Cancel:SetPoint("BOTTOMRIGHT", SetupFrame.bg1, -50, 60)
	LCI_Cancel:SetSize(100, 45)
	LCI_Cancel:SetNormalTexture(LCI_Media .. "button1")
	LCI_Cancel:SetScript("OnEnter", Button_OnEnter)
	LCI_Cancel:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Cancel Button Text]] --
	LCI_Cancel.txt = LCI_Cancel:CreateFontString(nil, "OVERLAY")
	LCI_Cancel.txt:SetPoint("CENTER", LCI_Cancel)
	LCI_Cancel.txt:SetFont(LCI_Font, 14)
	LCI_Cancel.txt:SetText(L["Cancel"])
	
	-- [[Cancel Button Script]] --
	LCI_Cancel:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		SetupFrame:Hide()
	end)
end

-- [[Step 6: Finish Installation]] --
function LCI:Finish()
	LCI.db.profile.IsInstalled = true
	
	ReloadUI()
end

function LCI:SetupPage6()
	-- [[Page 6 Text]] --
	SetupFrame.pg6txt = SetupFrame:CreateFontString(nil, "OVERLAY")
	SetupFrame.pg6txt:SetPoint("TOP", SetupFrame.bg2, 0, -50)
	SetupFrame.pg6txt:SetFont(LCI_Font, 14)
	SetupFrame.pg6txt:SetText(L["Finish Install"])
	
	-- [[Finish Button]] --
	local Finish = CreateFrame("Button", nil, SetupFrame)
	Finish:SetPoint("BOTTOMLEFT", SetupFrame.bg2, 50, 60)
	Finish:SetSize(100, 45)
	Finish:SetNormalTexture(LCI_Media .. "button1")
	Finish:SetScript("OnEnter", Button_OnEnter)
	Finish:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Finish Button Text]] --
	Finish.txt = Finish:CreateFontString(nil, "OVERLAY")
	Finish.txt:SetPoint("CENTER", Finish)
	Finish.txt:SetFont(LCI_Font, 14)
	Finish.txt:SetText(L["Finish"])
	
	-- [[Finish Button Script]] --
	Finish:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		SetupFrame:Hide()
		LCI:Finish()
	end)
end

-- [[Step 5: Install Saved Variables]] --
function LCI:Install()
	if LCI.db.profile.ResTypeSet == "1920x1080" then
		SetCVar("useUiScale", "1");
		SetCVar("uiScale", "0.65");
	end
	
	--[[if IsAddOnLoaded("Bartender4") then
		LCI:Install_Bartender4()
	end	
	if IsAddOnLoaded("BasicChatMods") then
		LCI:Install_BasicChatMods()
	end	
	if IsAddOnLoaded("BasicMinimap") then
		LCI:Install_BasicMinimap()
	end	
	if IsAddOnLoaded("Bazooka") then
		LCI:Install_Bazooka()
	end
	if IsAddOnLoaded("Broker_BagInfo") then
		LCI:Install_Broker_BagInfo()
	end	
	if IsAddOnLoaded("Broker_Garrison") then
		LCI:Install_Broker_Garrison()
	end	
	if IsAddOnLoaded("Broker_Money") then
		LCI:Install_Broker_Money()
	end	
	if IsAddOnLoaded("Broker_uClock") then
		LCI:Install_Broker_uClock()
	end	
	if IsAddOnLoaded("broker_gg_socialstate") then
		LCI:Install_GGSocialState()
	end	
	if IsAddOnLoaded("DBM-Core") then
		LCI:Install_DBM()
	end	
	if IsAddOnLoaded("GearGrinder") then
		LCI:Install_GearGrinder()
	end	
	if IsAddOnLoaded("Masque") then
		LCI:Install_Masque()
	end	
	if IsAddOnLoaded("MoveAnything") then
		LCI:Install_MoveAnything()
	end	
	if IsAddOnLoaded("MSBT") then
		LCI:Install_MSBT()
	end	
	if IsAddOnLoaded("NOP") then
		LCI:Install_NOP()
	end	
	if IsAddOnLoaded("Omen") then
		LCI:Install_Omen()
	end	
	if IsAddOnLoaded("OmniCC") then
		LCI:Install_OmniCC()
	end	
	if IsAddOnLoaded("PhanxBuffs") then
		LCI:Install_PhanxBuffs()
	end	
	if IsAddOnLoaded("Quartz") then
		LCI:Install_Quartz()
	end	
	if IsAddOnLoaded("SacriRaidBuffed") then
		LCI:Install_SacriRaidBuffed()
	end	
	if IsAddOnLoaded("ShadowedUnitFrames") then
		LCI:Install_ShadowedUnitFrames()
	end	
	if IsAddOnLoaded("SimplePowerBar") then
		LCI:Install_SimplePowerBar()
	end	
	if IsAddOnLoaded("Skada") then
		LCI:Install_Skada()
	end	
	if IsAddOnLoaded("SmartRes2") then
		LCI:Install_SmartRes2()
	end	
	if IsAddOnLoaded("TipTac") then
		LCI:Install_TipTac()
	end	
	if IsAddOnLoaded("TidyPlates") then
		LCI:Install_TidyPlates()
	end	
	if IsAddOnLoaded("TomTom") then
		LCI:Install_TomTom()
	end	
	if IsAddOnLoaded("XLoot") then
		LCI:Install_XLoot()
	end	]]
	
	LCI:ChatSettings()
	
	LCI:SetupPage6()
end

function LCI:SetupPage5()
	
	-- [[Page 5 Text]] --
	SetupFrame.pg5txt = SetupFrame:CreateFontString(nil, "OVERLAY")
	SetupFrame.pg5txt:SetPoint("TOP", SetupFrame.bg2, 0, -50)
	SetupFrame.pg5txt:SetFont(LCI_Font, 14)
	SetupFrame.pg5txt:SetText(L["Install Variables"])
	
	-- [[Install Button]] --
	LCI_Install = CreateFrame("Button", nil, SetupFrame)
	LCI_Install:SetPoint("BOTTOMLEFT", SetupFrame.bg2, 50, 60)
	LCI_Install:SetSize(100, 45)
	LCI_Install:SetNormalTexture(LCI_Media .. "button1")
	LCI_Install:SetScript("OnEnter", Button_OnEnter)
	LCI_Install:SetScript("OnLeave", Button_OnLeave)

	-- [[Install Button Text]] --
	LCI_Install.txt = LCI_Install:CreateFontString(nil, "OVERLAY")
	LCI_Install.txt:SetPoint("CENTER", LCI_Install)
	LCI_Install.txt:SetFont(LCI_Font, 14)
	LCI_Install.txt:SetText(L["Install"])
	
	-- [[Install Button Script]] --
	LCI_Install:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI:Install()
		SetupFrame.pg5txt:Hide()
		LCI_Install:Hide()
	end)
end

-- [[Step 4: Enables LCI Features]] --
function LCI:SetupPage4()	
	
	-- [[Page 4 Text]] --
	SetupFrame.pg4txt = SetupFrame:CreateFontString(nil, "OVERLAY")
	SetupFrame.pg4txt:SetPoint("TOP", SetupFrame.bg2, 0, -50)
	SetupFrame.pg4txt:SetFont(LCI_Font, 14)
	SetupFrame.pg4txt:SetText(L["LCI Features"])
	
	-- [[Place Holder]] --
	
end

-- [[Step 3: Layout Selection]] --
function LCI:SetupPage3()
	-- [[Page 3 Text]] --
	SetupFrame.pg3txt = SetupFrame:CreateFontString(nil, "OVERLAY")
	SetupFrame.pg3txt:SetPoint("TOP", SetupFrame.bg2, 0, -50)
	SetupFrame.pg3txt:SetFont(LCI_Font, 14)
	SetupFrame.pg3txt:SetText(L["Layout Selection"])
	
	-- [[Healer Layout Button]] --
	LCI_Layout_H = CreateFrame("Button", nil, SetupFrame)
	LCI_Layout_H:SetPoint("RIGHT", SetupFrame.bg2, "CENTER", -25, 0)
	LCI_Layout_H:SetSize(100, 50)
	LCI_Layout_H:SetNormalTexture(LCI_Media .. "button1")
	LCI_Layout_H:SetScript("OnEnter", Button_OnEnter)
	LCI_Layout_H:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Healer Layout Button Text]] --
	LCI_Layout_H.txt = LCI_Layout_H:CreateFontString(nil, "OVERLAY")
	LCI_Layout_H.txt:SetPoint("CENTER", LCI_Layout_H)
	LCI_Layout_H.txt:SetFont(LCI_Font, 14)
	LCI_Layout_H.txt:SetText(L["Healer"])
	
	-- [[Healer Layout Button Script]] --
	LCI_Layout_H:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.LayoutTypeSet = "Healer"
		SetupFrame.pg3txt:SetText(L["Layout selected: "].. "|cFFCC00CC".. L["Healer"].. "|r")
	end)
	
	-- [[Tank/DPS Layout Button]] --
	LCI_Layout_TD = CreateFrame("Button", nil, SetupFrame)
	LCI_Layout_TD:SetPoint("LEFT", SetupFrame.bg2, "CENTER", 25, 0)
	LCI_Layout_TD:SetSize(100, 50)
	LCI_Layout_TD:SetNormalTexture(LCI_Media .. "button1")
	LCI_Layout_TD:SetScript("OnEnter", Button_OnEnter)
	LCI_Layout_TD:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Tank/DPS Layout Button Text]] --
	LCI_Layout_TD.txt = LCI_Layout_TD:CreateFontString(nil, "OVERLAY")
	LCI_Layout_TD.txt:SetPoint("CENTER", LCI_Layout_TD)
	LCI_Layout_TD.txt:SetFont(LCI_Font, 14)
	LCI_Layout_TD.txt:SetText(L["Tank/DPS"])
	
	-- [[Tank/DPS Layout Button Script]] --
	LCI_Layout_TD:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.LayoutTypeSet = "Tank/DPS"
		SetupFrame.pg3txt:SetText(L["Layout selected: "].. "|cFFCC00CC".. L["Tank/DPS"].. "|r")
	end)
end

-- [[Step 2.5: Resolution Selection Window]] --
function LCI:ResWindow()

	-- [[Res Window Text]] --
	SetupFrame.rwtxt = SetupFrame:CreateFontString(nil, "OVERLAY")
	SetupFrame.rwtxt:SetPoint("TOP", SetupFrame.bg2, 0, -50)
	SetupFrame.rwtxt:SetFont(LCI_Font, 14)
	SetupFrame.rwtxt:SetText(L["Select Resolution"])
	
	-- [[Res1 Button]] --
	LCI_Res1 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res1:SetPoint("CENTER", SetupFrame.bg2, -100, 75)
	LCI_Res1:SetSize(90, 30)
	LCI_Res1:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res1:SetScript("OnEnter", Button_OnEnter)
	LCI_Res1:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res1 Button Text]] --
	LCI_Res1.txt = LCI_Res1:CreateFontString(nil, "OVERLAY")
	LCI_Res1.txt:SetPoint("CENTER", LCI_Res1)
	LCI_Res1.txt:SetFont(LCI_Font, 14)
	LCI_Res1.txt:SetText("1920x1080")
	
	-- [[Res1 Button Script]] --
	LCI_Res1:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = "1920x1080"
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CC1920x1080|r")
	end)
	
	-- [[Res2 Button]] --
	LCI_Res2 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res2:SetPoint("CENTER", SetupFrame.bg2, 0, 75)
	LCI_Res2:SetSize(90, 30)
	LCI_Res2:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res2:SetScript("OnEnter", Button_OnEnter)
	LCI_Res2:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res2 Button Text]] --
	LCI_Res2.txt = LCI_Res2:CreateFontString(nil, "OVERLAY")
	LCI_Res2.txt:SetPoint("CENTER", LCI_Res2)
	LCI_Res2.txt:SetFont(LCI_Font, 14)
	LCI_Res2.txt:SetText("Res2")
	
	-- [[Res2 Button Script]] --
	LCI_Res2:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res2
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes2|r")
	end)
	
	-- [[Res3 Button]] --
	LCI_Res3 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res3:SetPoint("CENTER", SetupFrame.bg2, 100, 75)
	LCI_Res3:SetSize(90, 30)
	LCI_Res3:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res3:SetScript("OnEnter", Button_OnEnter)
	LCI_Res3:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res3 Button Text]] --
	LCI_Res3.txt = LCI_Res3:CreateFontString(nil, "OVERLAY")
	LCI_Res3.txt:SetPoint("CENTER", LCI_Res3)
	LCI_Res3.txt:SetFont(LCI_Font, 14)
	LCI_Res3.txt:SetText("Res3")
	
	-- [[Res3 Button Script]] --
	LCI_Res3:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res3
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes3|r")
	end)

	-- [[Res4 Button]] --
	LCI_Res4 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res4:SetPoint("CENTER", SetupFrame.bg2, -100, 45)
	LCI_Res4:SetSize(90, 30)
	LCI_Res4:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res4:SetScript("OnEnter", Button_OnEnter)
	LCI_Res4:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res4 Button Text]] --
	LCI_Res4.txt = LCI_Res4:CreateFontString(nil, "OVERLAY")
	LCI_Res4.txt:SetPoint("CENTER", LCI_Res4)
	LCI_Res4.txt:SetFont(LCI_Font, 14)
	LCI_Res4.txt:SetText("Res4")
	
	-- [[Res4 Button Script]] --
	LCI_Res4:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res4
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes4|r")
	end)
	
	-- [[Res5 Button]] --
	LCI_Res5 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res5:SetPoint("CENTER", SetupFrame.bg2, 0, 45)
	LCI_Res5:SetSize(90, 30)
	LCI_Res5:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res5:SetScript("OnEnter", Button_OnEnter)
	LCI_Res5:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res5 Button Text]] --
	LCI_Res5.txt = LCI_Res5:CreateFontString(nil, "OVERLAY")
	LCI_Res5.txt:SetPoint("CENTER", LCI_Res5)
	LCI_Res5.txt:SetFont(LCI_Font, 14)
	LCI_Res5.txt:SetText("Res5")
	
	-- [[Res5 Button Script]] --
	LCI_Res5:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res5
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes5|r")
	end)
	
	-- [[Res6 Button]] --
	LCI_Res6 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res6:SetPoint("CENTER", SetupFrame.bg2, 100, 45)
	LCI_Res6:SetSize(90, 30)
	LCI_Res6:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res6:SetScript("OnEnter", Button_OnEnter)
	LCI_Res6:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res6 Button Text]] --
	LCI_Res6.txt = LCI_Res6:CreateFontString(nil, "OVERLAY")
	LCI_Res6.txt:SetPoint("CENTER", LCI_Res6)
	LCI_Res6.txt:SetFont(LCI_Font, 14)
	LCI_Res6.txt:SetText("Res6")
	
	-- [[Res6 Button Script]] --
	LCI_Res6:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res6
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes6|r")
	end)
	
	-- [[Res7 Button]] --
	LCI_Res7 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res7:SetPoint("CENTER", SetupFrame.bg2, -100, 15)
	LCI_Res7:SetSize(90, 30)
	LCI_Res7:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res7:SetScript("OnEnter", Button_OnEnter)
	LCI_Res7:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res7 Button Text]] --
	LCI_Res7.txt = LCI_Res7:CreateFontString(nil, "OVERLAY")
	LCI_Res7.txt:SetPoint("CENTER", LCI_Res7)
	LCI_Res7.txt:SetFont(LCI_Font, 14)
	LCI_Res7.txt:SetText("Res7")
	
	-- [[Res7 Button Script]] --
	LCI_Res7:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res7
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes7|r")
	end)
	
	-- [[Res8 Button]] --
	LCI_Res8 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res8:SetPoint("CENTER", SetupFrame.bg2, 0, 15)
	LCI_Res8:SetSize(90, 30)
	LCI_Res8:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res8:SetScript("OnEnter", Button_OnEnter)
	LCI_Res8:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res8 Button Text]] --
	LCI_Res8.txt = LCI_Res8:CreateFontString(nil, "OVERLAY")
	LCI_Res8.txt:SetPoint("CENTER", LCI_Res8)
	LCI_Res8.txt:SetFont(LCI_Font, 14)
	LCI_Res8.txt:SetText("Res8")
	
	-- [[Res8 Button Script]] --
	LCI_Res8:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res8
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes8|r")
	end)
	
	-- [[Res9 Button]] --
	LCI_Res9 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res9:SetPoint("CENTER", SetupFrame.bg2, 100, 15)
	LCI_Res9:SetSize(90, 30)
	LCI_Res9:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res9:SetScript("OnEnter", Button_OnEnter)
	LCI_Res9:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res9 Button Text]] --
	LCI_Res9.txt = LCI_Res9:CreateFontString(nil, "OVERLAY")
	LCI_Res9.txt:SetPoint("CENTER", LCI_Res9)
	LCI_Res9.txt:SetFont(LCI_Font, 14)
	LCI_Res9.txt:SetText("Res9")
	
	-- [[Res9 Button Script]] --
	LCI_Res9:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res9
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes9|r")
	end)
	
	-- [[Res10 Button]] --
	LCI_Res10 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res10:SetPoint("CENTER", SetupFrame.bg2, -100, -15)
	LCI_Res10:SetSize(90, 30)
	LCI_Res10:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res10:SetScript("OnEnter", Button_OnEnter)
	LCI_Res10:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res10 Button Text]] --
	LCI_Res10.txt = LCI_Res10:CreateFontString(nil, "OVERLAY")
	LCI_Res10.txt:SetPoint("CENTER", LCI_Res10)
	LCI_Res10.txt:SetFont(LCI_Font, 14)
	LCI_Res10.txt:SetText("Res10")
	
	-- [[Res10 Button Script]] --
	LCI_Res10:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res10
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes10|r")
	end)
	
	-- [[Res11 Button]] --
	LCI_Res11 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res11:SetPoint("CENTER", SetupFrame.bg2, 0, -15)
	LCI_Res11:SetSize(90, 30)
	LCI_Res11:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res11:SetScript("OnEnter", Button_OnEnter)
	LCI_Res11:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res11 Button Text]] --
	LCI_Res11.txt = LCI_Res11:CreateFontString(nil, "OVERLAY")
	LCI_Res11.txt:SetPoint("CENTER", LCI_Res11)
	LCI_Res11.txt:SetFont(LCI_Font, 14)
	LCI_Res11.txt:SetText("Res11")
	
	-- [[Res11 Button Script]] --
	LCI_Res11:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res11
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes11|r")
	end)
	
	-- [[Res12 Button]] --
	LCI_Res12 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res12:SetPoint("CENTER", SetupFrame.bg2, 100, -15)
	LCI_Res12:SetSize(90, 30)
	LCI_Res12:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res12:SetScript("OnEnter", Button_OnEnter)
	LCI_Res12:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res12 Button Text]] --
	LCI_Res12.txt = LCI_Res12:CreateFontString(nil, "OVERLAY")
	LCI_Res12.txt:SetPoint("CENTER", LCI_Res12)
	LCI_Res12.txt:SetFont(LCI_Font, 14)
	LCI_Res12.txt:SetText("Res12")
	
	-- [[Res12 Button Script]] --
	LCI_Res12:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res12
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes12|r")
	end)
	
	-- [[Res13 Button]] --
	LCI_Res13 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res13:SetPoint("CENTER", SetupFrame.bg2, -100, -45)
	LCI_Res13:SetSize(90, 30)
	LCI_Res13:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res13:SetScript("OnEnter", Button_OnEnter)
	LCI_Res13:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res13 Button Text]] --
	LCI_Res13.txt = LCI_Res13:CreateFontString(nil, "OVERLAY")
	LCI_Res13.txt:SetPoint("CENTER", LCI_Res13)
	LCI_Res13.txt:SetFont(LCI_Font, 14)
	LCI_Res13.txt:SetText("Res13")
	
	-- [[Res13 Button Script]] --
	LCI_Res13:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res13
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes13|r")
	end)
	
	-- [[Res14 Button]] --
	LCI_Res14 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res14:SetPoint("CENTER", SetupFrame.bg2, 0, -45)
	LCI_Res14:SetSize(90, 30)
	LCI_Res14:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res14:SetScript("OnEnter", Button_OnEnter)
	LCI_Res14:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res14 Button Text]] --
	LCI_Res14.txt = LCI_Res14:CreateFontString(nil, "OVERLAY")
	LCI_Res14.txt:SetPoint("CENTER", LCI_Res14)
	LCI_Res14.txt:SetFont(LCI_Font, 14)
	LCI_Res14.txt:SetText("Res14")
	
	-- [[Res14 Button Script]] --
	LCI_Res14:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res14
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes14|r")
	end)
	
	-- [[Res15 Button]] --
	LCI_Res15 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res15:SetPoint("CENTER", SetupFrame.bg2, 100, -45)
	LCI_Res15:SetSize(90, 30)
	LCI_Res15:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res15:SetScript("OnEnter", Button_OnEnter)
	LCI_Res15:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res15 Button Text]] --
	LCI_Res15.txt = LCI_Res15:CreateFontString(nil, "OVERLAY")
	LCI_Res15.txt:SetPoint("CENTER", LCI_Res15)
	LCI_Res15.txt:SetFont(LCI_Font, 14)
	LCI_Res15.txt:SetText("Res15")
	
	-- [[Res15 Button Script]] --
	LCI_Res15:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res15
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes15|r")
	end)
	
	-- [[Res16 Button]] --
	LCI_Res16 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res16:SetPoint("CENTER", SetupFrame.bg2, -100, -75)
	LCI_Res16:SetSize(90, 30)
	LCI_Res16:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res16:SetScript("OnEnter", Button_OnEnter)
	LCI_Res16:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res16 Button Text]] --
	LCI_Res16.txt = LCI_Res16:CreateFontString(nil, "OVERLAY")
	LCI_Res16.txt:SetPoint("CENTER", LCI_Res16)
	LCI_Res16.txt:SetFont(LCI_Font, 14)
	LCI_Res16.txt:SetText("Res16")
	
	-- [[Res16 Button Script]] --
	LCI_Res16:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res16
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes16|r")
	end)
	
	-- [[Res17 Button]] --
	LCI_Res17 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res17:SetPoint("CENTER", SetupFrame.bg2, 0, -75)
	LCI_Res17:SetSize(90, 30)
	LCI_Res17:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res17:SetScript("OnEnter", Button_OnEnter)
	LCI_Res17:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res17 Button Text]] --
	LCI_Res17.txt = LCI_Res17:CreateFontString(nil, "OVERLAY")
	LCI_Res17.txt:SetPoint("CENTER", LCI_Res17)
	LCI_Res17.txt:SetFont(LCI_Font, 14)
	LCI_Res17.txt:SetText("Res17")
	
	-- [[Res17 Button Script]] --
	LCI_Res17:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res17
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes17|r")
	end)
	
	-- [[Res18 Button]] --
	LCI_Res18 = CreateFrame("Button", nil, SetupFrame)
	LCI_Res18:SetPoint("CENTER", SetupFrame.bg2, 100, -75)
	LCI_Res18:SetSize(90, 30)
	LCI_Res18:SetNormalTexture(LCI_Media .. "button1")
	LCI_Res18:SetScript("OnEnter", Button_OnEnter)
	LCI_Res18:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Res18 Button Text]] --
	LCI_Res18.txt = LCI_Res18:CreateFontString(nil, "OVERLAY")
	LCI_Res18.txt:SetPoint("CENTER", LCI_Res18)
	LCI_Res18.txt:SetFont(LCI_Font, 14)
	LCI_Res18.txt:SetText("Res18")
	
	-- [[Res18 Button Script]] --
	LCI_Res18:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI.db.profile.ResTypeSet = Res18
		SetupFrame.rwtxt:SetText(L["Resolution selected: "].. "|cFFCC00CCRes18|r")
	end)
end

-- [[Step 2: Confirm Resolution]] --
function LCI:SetupPage2()
	local currentResolution = ({GetScreenResolutions()})[GetCurrentResolution()]

	-- [[Blank background]] --
	SetupFrame.bg2 = SetupFrame:CreateTexture(nil, "ARTWORK")
	SetupFrame.bg2:SetPoint("CENTER", SetupFrame)
	SetupFrame.bg2:SetSize(500, 500)
	SetupFrame.bg2:SetTexture(LCI_Media .. "bg_blank")
	
	-- [[Page 4 Text]] --
	SetupFrame.pg2txt = SetupFrame:CreateFontString(nil, "OVERLAY")
	SetupFrame.pg2txt:SetPoint("TOP", SetupFrame.bg2, 0, -50)
	SetupFrame.pg2txt:SetFont(LCI_Font, 14)
	if LCI_resFound == true then
		SetupFrame.pg2txt:SetText(L["Resolution detected: "].. "|cFFCC00CC".. currentResolution.. "|r".. L["Correct Resolution"])
	else 
		SetupFrame.pg2txt:SetText(L["Incorrect Resolution"])
	end
	
	-- [[Select Button]] --
	LCI_Select = CreateFrame("Button", nil, SetupFrame)
	LCI_Select:SetPoint("CENTER", SetupFrame.bg2)
	LCI_Select:SetSize(100, 45)
	LCI_Select:SetNormalTexture(LCI_Media .. "button1")
	LCI_Select:SetScript("OnEnter", Button_OnEnter)
	LCI_Select:SetScript("OnLeave", Button_OnLeave)
	
	-- [[Select Button Text]] --
	LCI_Select.txt = LCI_Select:CreateFontString(nil, "OVERLAY")
	LCI_Select.txt:SetPoint("CENTER", LCI_Select)
	LCI_Select.txt:SetFont(LCI_Font, 14)
	LCI_Select.txt:SetText(L["Select"])
	
	-- [[Select Button Script]] --
	LCI_Select:SetScript("OnClick", function(this)
		PlaySoundFile(LCI_Media .. "Sound\\click.ogg")
		LCI_Select:Hide()
		SetupFrame.pg2txt:Hide()
		LCI:ResWindow()
	end)
end

-- [[Step 1: Initiate Setup Window]] --
function LCI:InitSetup()

	--[[Global Setup Window Settings]] --
	SetupFrame = CreateFrame("Frame", "LCISetupFrame", UIParent)
	SetupFrame:SetPoint("CENTER")
	SetupFrame:SetSize(800, 800)
	SetupFrame:SetScale(1)
	SetupFrame:SetFrameStrata("FULLSCREEN_DIALOG")
	SetupFrame:SetFrameLevel("5")
	
	local alpha = SetupFrame:CreateTexture(nil, "BACKGROUND")
	alpha:SetAllPoints(UIParent)
	alpha:SetTexture(0, 0, 0, 0.8)
	
	-- [[Page 1 Background]] --
	SetupFrame.bg1 = SetupFrame:CreateTexture(nil, "ARTWORK")
	SetupFrame.bg1:SetPoint("CENTER", SetupFrame)
	SetupFrame.bg1:SetSize(500, 500)
	SetupFrame.bg1:SetTexture(LCI_Media .. "bg_art")

	-- [[Page 1 Text]] --
	SetupFrame.pg1txt = SetupFrame:CreateFontString(nil, "OVERLAY")
	SetupFrame.pg1txt:SetPoint("TOP", SetupFrame.bg1, 0, -50)
	SetupFrame.pg1txt:SetFont(LCI_Font, 14)
	SetupFrame.pg1txt:SetText(L["Welcome"])
	
	LCI:Continue_Button()
	LCI:Cancel_Button()
end

